@@ -149,7 +149,6 @@
 }
 
 
-
 # workhorse ------------------------
 
 .extract_random_variances_helper <- function(model,
@@ -206,7 +205,7 @@
   # rename columns
   out <- datawizard::data_rename(
     out,
-    pattern = c("grp", "sdcor"),
+    select = c("grp", "sdcor"),
     replacement = c("Group", "Coefficient")
   )
 
@@ -268,7 +267,6 @@
 }
 
 
-
 #' @export
 as.data.frame.VarCorr.lme <- function(x, row.names = NULL, optional = FALSE, ...) {
   # retrieve RE SD and COR
@@ -334,9 +332,6 @@ as.data.frame.VarCorr.lme <- function(x, row.names = NULL, optional = FALSE, ...
 }
 
 
-
-
-
 # extract CI for random SD ------------------------
 
 .random_sd_ci <- function(model,
@@ -689,9 +684,6 @@ as.data.frame.VarCorr.lme <- function(x, row.names = NULL, optional = FALSE, ...
 }
 
 
-
-
-
 # Extract Variance and Correlation Components ----
 
 # store essential information about variance components...
@@ -843,9 +835,6 @@ as.data.frame.VarCorr.lme <- function(x, row.names = NULL, optional = FALSE, ...
 }
 
 
-
-
-
 # glmmTMB returns a list of model information, one for conditional
 # and one for zero-inflation part, so here we "unlist" it, returning
 # only the conditional part.
