@@ -6,14 +6,46 @@
 
 #################### .glimML ------
 
-
-#' @rdname model_parameters.averaging
+#' @title Parameters from special models
+#' @name model_parameters.glimML
+#'
+#' @description
+#' Parameters from special regression models not listed under one of the
+#' previous categories yet.
+#'
+#' @param component Model component for which parameters should be shown. May be
+#' one of `"conditional"`, `"precision"` (e.g. **betareg**), `"scale"` (e.g.
+#' **ordinal**), `"extra"` (e.g. **glmx**), `"marginal"` (e.g. **mfx**),
+#' `"conditional"` or `"full"` (for `MuMIn::model.avg()`) or `"all"`. See section
+#' _Model components_ for an overview of possible options for `component`.
+#' @inheritParams model_parameters.default
+#' @inheritParams model_parameters.brmsfit
+#' @inheritParams simulate_model
+#'
+#' @seealso [insight::standardize_names()] to rename columns into a consistent,
+#' standardized naming scheme.
+#'
+#' @inheritSection model_parameters.zcpglm Model components
+#'
+#' @examples
+#' library(parameters)
+#' if (require("brglm2", quietly = TRUE)) {
+#'   data("stemcell")
+#'   model <- bracl(
+#'     research ~ as.numeric(religion) + gender,
+#'     weights = frequency,
+#'     data = stemcell,
+#'     type = "ML"
+#'   )
+#'   model_parameters(model)
+#' }
+#' @return A data frame of indices related to the model's parameters.
 #' @export
 model_parameters.glimML <- function(model,
                                     ci = 0.95,
                                     bootstrap = FALSE,
                                     iterations = 1000,
-                                    component = c("conditional", "random", "dispersion", "all"),
+                                    component = "conditional",
                                     standardize = NULL,
                                     exponentiate = FALSE,
                                     p_adjust = NULL,
@@ -23,7 +55,10 @@ model_parameters.glimML <- function(model,
                                     drop = NULL,
                                     verbose = TRUE,
                                     ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("conditional", "random", "dispersion", "all")
+  )
   if (component == "all") {
     merge_by <- c("Parameter", "Component")
   } else {
