@@ -426,7 +426,7 @@ ci.glmmTMB <- function(x,
   method <- tolower(method)
   method <- insight::validate_argument(
     method,
-    c("wald", "normal", "ml1", "betwithin", "profile", "uniroot", "robust")
+    c("wald", "normal", "ml1", "betwithin", "profile", "uniroot", "robust", "residual")
   )
   component <- insight::validate_argument(
     component,
@@ -533,8 +533,6 @@ standard_error.glmmTMB <- function(model,
 }
 
 
-
-
 # simulate model -----
 
 
@@ -627,8 +625,6 @@ simulate_model.glmmTMB <- function(model,
 }
 
 
-
-
 # simulate_parameters -----
 
 #' @export
